import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#allow_auto_merge Repository#allow_auto_merge}.
     *
     * @stability stable
     */
    readonly allowAutoMerge?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#allow_merge_commit Repository#allow_merge_commit}.
     *
     * @stability stable
     */
    readonly allowMergeCommit?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#allow_rebase_merge Repository#allow_rebase_merge}.
     *
     * @stability stable
     */
    readonly allowRebaseMerge?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#allow_squash_merge Repository#allow_squash_merge}.
     *
     * @stability stable
     */
    readonly allowSquashMerge?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#archive_on_destroy Repository#archive_on_destroy}.
     *
     * @stability stable
     */
    readonly archiveOnDestroy?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#archived Repository#archived}.
     *
     * @stability stable
     */
    readonly archived?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#auto_init Repository#auto_init}.
     *
     * @stability stable
     */
    readonly autoInit?: boolean | cdktf.IResolvable;
    /**
     * Can only be set after initial repository creation, and only if the target branch exists.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#default_branch Repository#default_branch}
     *
     * @stability stable
     */
    readonly defaultBranch?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#delete_branch_on_merge Repository#delete_branch_on_merge}.
     *
     * @stability stable
     */
    readonly deleteBranchOnMerge?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#description Repository#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#gitignore_template Repository#gitignore_template}.
     *
     * @stability stable
     */
    readonly gitignoreTemplate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#has_downloads Repository#has_downloads}.
     *
     * @stability stable
     */
    readonly hasDownloads?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#has_issues Repository#has_issues}.
     *
     * @stability stable
     */
    readonly hasIssues?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#has_projects Repository#has_projects}.
     *
     * @stability stable
     */
    readonly hasProjects?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#has_wiki Repository#has_wiki}.
     *
     * @stability stable
     */
    readonly hasWiki?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#homepage_url Repository#homepage_url}.
     *
     * @stability stable
     */
    readonly homepageUrl?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#is_template Repository#is_template}.
     *
     * @stability stable
     */
    readonly isTemplate?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#license_template Repository#license_template}.
     *
     * @stability stable
     */
    readonly licenseTemplate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#name Repository#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#private Repository#private}.
     *
     * @stability stable
     */
    readonly private?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#topics Repository#topics}.
     *
     * @stability stable
     */
    readonly topics?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#visibility Repository#visibility}.
     *
     * @stability stable
     */
    readonly visibility?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#vulnerability_alerts Repository#vulnerability_alerts}.
     *
     * @stability stable
     */
    readonly vulnerabilityAlerts?: boolean | cdktf.IResolvable;
    /**
     * pages block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#pages Repository#pages}
     *
     * @stability stable
     */
    readonly pages?: RepositoryPages;
    /**
     * template block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#template Repository#template}
     *
     * @stability stable
     */
    readonly template?: RepositoryTemplate;
}
/**
 * @stability stable
 */
export declare class RepositoryBranches extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get protected(): any;
}
/**
 * @stability stable
 */
export interface RepositoryPagesSource {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#branch Repository#branch}.
     *
     * @stability stable
     */
    readonly branch: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#path Repository#path}.
     *
     * @stability stable
     */
    readonly path?: string;
}
export declare function repositoryPagesSourceToTerraform(struct?: RepositoryPagesSourceOutputReference | RepositoryPagesSource): any;
/**
 * @stability stable
 */
export declare class RepositoryPagesSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RepositoryPagesSource | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RepositoryPagesSource | undefined);
    private _branch?;
    /**
     * @stability stable
     */
    get branch(): string;
    /**
     * @stability stable
     */
    set branch(value: string);
    /**
     * @stability stable
     */
    get branchInput(): string | undefined;
    private _path?;
    /**
     * @stability stable
     */
    get path(): string;
    /**
     * @stability stable
     */
    set path(value: string);
    /**
     * @stability stable
     */
    resetPath(): void;
    /**
     * @stability stable
     */
    get pathInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface RepositoryPages {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#cname Repository#cname}.
     *
     * @stability stable
     */
    readonly cname?: string;
    /**
     * source block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#source Repository#source}
     *
     * @stability stable
     */
    readonly source: RepositoryPagesSource;
}
export declare function repositoryPagesToTerraform(struct?: RepositoryPagesOutputReference | RepositoryPages): any;
/**
 * @stability stable
 */
export declare class RepositoryPagesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RepositoryPages | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RepositoryPages | undefined);
    private _cname?;
    /**
     * @stability stable
     */
    get cname(): string;
    /**
     * @stability stable
     */
    set cname(value: string);
    /**
     * @stability stable
     */
    resetCname(): void;
    /**
     * @stability stable
     */
    get cnameInput(): string | undefined;
    private _source;
    /**
     * @stability stable
     */
    get source(): RepositoryPagesSourceOutputReference;
    /**
     * @stability stable
     */
    putSource(value: RepositoryPagesSource): void;
    /**
     * @stability stable
     */
    get sourceInput(): RepositoryPagesSource | undefined;
}
/**
 * @stability stable
 */
export interface RepositoryTemplate {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#owner Repository#owner}.
     *
     * @stability stable
     */
    readonly owner: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/github/r/repository#repository Repository#repository}.
     *
     * @stability stable
     */
    readonly repository: string;
}
export declare function repositoryTemplateToTerraform(struct?: RepositoryTemplateOutputReference | RepositoryTemplate): any;
/**
 * @stability stable
 */
export declare class RepositoryTemplateOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): RepositoryTemplate | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: RepositoryTemplate | undefined);
    private _owner?;
    /**
     * @stability stable
     */
    get owner(): string;
    /**
     * @stability stable
     */
    set owner(value: string);
    /**
     * @stability stable
     */
    get ownerInput(): string | undefined;
    private _repository?;
    /**
     * @stability stable
     */
    get repository(): string;
    /**
     * @stability stable
     */
    set repository(value: string);
    /**
     * @stability stable
     */
    get repositoryInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/github/r/repository github_repository}.
 *
 * @stability stable
 */
export declare class Repository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/github/r/repository github_repository} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RepositoryConfig);
    private _allowAutoMerge?;
    /**
     * @stability stable
     */
    get allowAutoMerge(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowAutoMerge(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowAutoMerge(): void;
    /**
     * @stability stable
     */
    get allowAutoMergeInput(): boolean | cdktf.IResolvable | undefined;
    private _allowMergeCommit?;
    /**
     * @stability stable
     */
    get allowMergeCommit(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowMergeCommit(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowMergeCommit(): void;
    /**
     * @stability stable
     */
    get allowMergeCommitInput(): boolean | cdktf.IResolvable | undefined;
    private _allowRebaseMerge?;
    /**
     * @stability stable
     */
    get allowRebaseMerge(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowRebaseMerge(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowRebaseMerge(): void;
    /**
     * @stability stable
     */
    get allowRebaseMergeInput(): boolean | cdktf.IResolvable | undefined;
    private _allowSquashMerge?;
    /**
     * @stability stable
     */
    get allowSquashMerge(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set allowSquashMerge(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAllowSquashMerge(): void;
    /**
     * @stability stable
     */
    get allowSquashMergeInput(): boolean | cdktf.IResolvable | undefined;
    private _archiveOnDestroy?;
    /**
     * @stability stable
     */
    get archiveOnDestroy(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set archiveOnDestroy(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetArchiveOnDestroy(): void;
    /**
     * @stability stable
     */
    get archiveOnDestroyInput(): boolean | cdktf.IResolvable | undefined;
    private _archived?;
    /**
     * @stability stable
     */
    get archived(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set archived(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetArchived(): void;
    /**
     * @stability stable
     */
    get archivedInput(): boolean | cdktf.IResolvable | undefined;
    private _autoInit?;
    /**
     * @stability stable
     */
    get autoInit(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoInit(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoInit(): void;
    /**
     * @stability stable
     */
    get autoInitInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    branches(index: string): RepositoryBranches;
    private _defaultBranch?;
    /**
     * @stability stable
     */
    get defaultBranch(): string;
    /**
     * @stability stable
     */
    set defaultBranch(value: string);
    /**
     * @stability stable
     */
    resetDefaultBranch(): void;
    /**
     * @stability stable
     */
    get defaultBranchInput(): string | undefined;
    private _deleteBranchOnMerge?;
    /**
     * @stability stable
     */
    get deleteBranchOnMerge(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set deleteBranchOnMerge(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetDeleteBranchOnMerge(): void;
    /**
     * @stability stable
     */
    get deleteBranchOnMergeInput(): boolean | cdktf.IResolvable | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get fullName(): string;
    /**
     * @stability stable
     */
    get gitCloneUrl(): string;
    private _gitignoreTemplate?;
    /**
     * @stability stable
     */
    get gitignoreTemplate(): string;
    /**
     * @stability stable
     */
    set gitignoreTemplate(value: string);
    /**
     * @stability stable
     */
    resetGitignoreTemplate(): void;
    /**
     * @stability stable
     */
    get gitignoreTemplateInput(): string | undefined;
    private _hasDownloads?;
    /**
     * @stability stable
     */
    get hasDownloads(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasDownloads(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasDownloads(): void;
    /**
     * @stability stable
     */
    get hasDownloadsInput(): boolean | cdktf.IResolvable | undefined;
    private _hasIssues?;
    /**
     * @stability stable
     */
    get hasIssues(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasIssues(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasIssues(): void;
    /**
     * @stability stable
     */
    get hasIssuesInput(): boolean | cdktf.IResolvable | undefined;
    private _hasProjects?;
    /**
     * @stability stable
     */
    get hasProjects(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasProjects(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasProjects(): void;
    /**
     * @stability stable
     */
    get hasProjectsInput(): boolean | cdktf.IResolvable | undefined;
    private _hasWiki?;
    /**
     * @stability stable
     */
    get hasWiki(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasWiki(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasWiki(): void;
    /**
     * @stability stable
     */
    get hasWikiInput(): boolean | cdktf.IResolvable | undefined;
    private _homepageUrl?;
    /**
     * @stability stable
     */
    get homepageUrl(): string;
    /**
     * @stability stable
     */
    set homepageUrl(value: string);
    /**
     * @stability stable
     */
    resetHomepageUrl(): void;
    /**
     * @stability stable
     */
    get homepageUrlInput(): string | undefined;
    /**
     * @stability stable
     */
    get htmlUrl(): string;
    /**
     * @stability stable
     */
    get httpCloneUrl(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _isTemplate?;
    /**
     * @stability stable
     */
    get isTemplate(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isTemplate(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsTemplate(): void;
    /**
     * @stability stable
     */
    get isTemplateInput(): boolean | cdktf.IResolvable | undefined;
    private _licenseTemplate?;
    /**
     * @stability stable
     */
    get licenseTemplate(): string;
    /**
     * @stability stable
     */
    set licenseTemplate(value: string);
    /**
     * @stability stable
     */
    resetLicenseTemplate(): void;
    /**
     * @stability stable
     */
    get licenseTemplateInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get nodeId(): string;
    private _private?;
    /**
     * @stability stable
     */
    get private(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set private(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPrivate(): void;
    /**
     * @stability stable
     */
    get privateInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get repoId(): number;
    /**
     * @stability stable
     */
    get sshCloneUrl(): string;
    /**
     * @stability stable
     */
    get svnUrl(): string;
    private _topics?;
    /**
     * @stability stable
     */
    get topics(): string[];
    /**
     * @stability stable
     */
    set topics(value: string[]);
    /**
     * @stability stable
     */
    resetTopics(): void;
    /**
     * @stability stable
     */
    get topicsInput(): string[] | undefined;
    private _visibility?;
    /**
     * @stability stable
     */
    get visibility(): string;
    /**
     * @stability stable
     */
    set visibility(value: string);
    /**
     * @stability stable
     */
    resetVisibility(): void;
    /**
     * @stability stable
     */
    get visibilityInput(): string | undefined;
    private _vulnerabilityAlerts?;
    /**
     * @stability stable
     */
    get vulnerabilityAlerts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set vulnerabilityAlerts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetVulnerabilityAlerts(): void;
    /**
     * @stability stable
     */
    get vulnerabilityAlertsInput(): boolean | cdktf.IResolvable | undefined;
    private _pages;
    /**
     * @stability stable
     */
    get pages(): RepositoryPagesOutputReference;
    /**
     * @stability stable
     */
    putPages(value: RepositoryPages): void;
    /**
     * @stability stable
     */
    resetPages(): void;
    /**
     * @stability stable
     */
    get pagesInput(): RepositoryPages | undefined;
    private _template;
    /**
     * @stability stable
     */
    get template(): RepositoryTemplateOutputReference;
    /**
     * @stability stable
     */
    putTemplate(value: RepositoryTemplate): void;
    /**
     * @stability stable
     */
    resetTemplate(): void;
    /**
     * @stability stable
     */
    get templateInput(): RepositoryTemplate | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
